@@ -43,7 +43,7 @@ colourScale.factor = function(x=NULL, breaks=5,
 		col="YlOrRd", opacity=1, dec=NULL, firstBreak=NULL, 
 		transform=NULL, revCol=FALSE, exclude=NULL, labels=NULL,...) {
 
-	res=colourScale(as.integer(x), 
+	res=colourScale(x=as.integer(x), 
 			breaks=breaks,
 			style="unique",
 			col=col, opacity=opacity, dec=dec, firstBreak=firstBreak, 
@@ -61,10 +61,11 @@ transform=NULL, revCol=FALSE, exclude=NULL, labels=NULL,...) {
 style = style[1]
 weights=NULL
 
-NforSample = 5e+05
+NforSample = 1e+05
 
-if(is.character(col)){
-if(col[1]=='radar'){
+if(is.character(col) ){
+	
+if(identical(col[1],'radar')){
 	col = radarCol
 }
 }
@@ -82,13 +83,56 @@ if(col[1]=='radar'){
 		x = NULL
 } else if(style=='unique') {
 
+	# if labels is missing, take labels from the raster
     if(is.null(labels)){
-      levelsx = levels(x)[[1]]
-    } else {
-      # if labels is a data frame, use it
-      if(is.data.frame(labels)) {
+      labels = levels(x)[[1]]
+    }
+		
+    # if labels is a data frame, use it
+    if(is.data.frame(labels)) {
         levelsx = labels
-      } else if(
+				# ID variable is first column if it's missing
+				if(!any(colnames(levelsx)=='ID')){
+					colnames(levelsx)[1] = 'ID'
+				}
+				
+				# if a factor or characters, convert to numeric
+				if(!is.numeric(levelsx$ID)) {
+					levelsx$ID = as.numeric(gsub(
+									"^[[:alpha:]]+", "", as.character(levelsx$ID)
+							))
+				}
+					
+				
+				# different spellings of 'label'
+				if(!any(colnames(levelsx)=='label')){
+					labelCol = grep("^label(s?)([[:space:]]?)|^NAME$", names(levelsx), ignore.case=TRUE)
+					if(length(labelCol)){
+						labelCol = labelCol[1]
+					} else {
+						labelCol = 2
+					}
+					colnames(levelsx)[labelCol] = 'label'
+				}
+				# convert factor or numbers to character
+				levelsx$label = as.character(levelsx$label)
+				
+				rgbCols = mapply(grep, 
+						pattern=paste('^', c("red",'green','blue'), '$', sep=''),
+						MoreArgs = list(x=names(levelsx), ignore.case=TRUE)
+				)
+				# if all three (rgb) are found
+				if(is.numeric(rgbCols)){
+					col = levelsx[,rgbCols, drop=FALSE]
+					breaks = nrow(col)
+				}
+				
+				colCol = grep("^col$", colnames(levelsx), ignore.case=TRUE)
+				if(length(colCol)) {
+					col = levelsx[,colCol]
+					breaks = length(col)
+				}
+      } else if( # labels not a data frame
           length(labels) == length(breaks)
           ){
         levelsx = data.frame(
@@ -105,20 +149,26 @@ if(col[1]=='radar'){
           warning('labels must be same length as either breaks or unique(x)')
           levelsx$label = as.character(levelsx$ID)
         }
-      } # end different numbers of levels and breaks
+    } # end different numbers of levels and breaks
       
-  	} # labels is not null
     
     if(ncell(x)<1e+06) {
-      x = freq(x)
+      x = freq(x, useNA='no')
       weights = x[,2]
       x=x[,1]
     } else {
-      x = table(
+      weights = table(
               sampleRegular(x, NforSample)
       )
-      weights = x
-      x = as.numeric(names(x))
+      x = as.numeric(names(weights))
+			if(!is.null(levelsx)) {
+				# check for values which are missing
+				toAdd = setdiff(levelsx$ID, x)
+				toAddWeights = rep(0, length(toAdd))
+				names(toAddWeights) = as.character(toAdd)
+				x = c(x, toAdd)
+				weights = c(weights, toAddWeights)
+			}
     }
     
     if(is.null(levelsx)){
@@ -135,13 +185,16 @@ if(col[1]=='radar'){
     levelsx = rbind(levelsx, toAdd)
     levelsx = levelsx[order(levelsx$ID),]
     } # end add more ID in levels
-    if(is.vector(labels)){
-      if(length(labels)==nrow(levelsx))
-        levelsx$label = labels
-    } # end labels are vector
-    if(is.null(levelsx$label))
-      levelsx$label = as.character(levelsx$ID)
-    
+    if(is.null(levelsx$label)) {
+    	if(is.vector(labels)){
+      	if(length(labels)==nrow(levelsx))
+        	levelsx$label = labels
+    	} # end labels are vector
+  	}
+	  if(is.null(levelsx$label)) {
+  		levelsx$label = as.character(levelsx$ID)
+		}
+	
     levelsx$freq = weights[match(
             levelsx$ID,
             x
@@ -151,16 +204,6 @@ if(col[1]=='radar'){
   if(length(breaks)==1 & all(breaks > nrow(levelsx)))
     breaks = levelsx$ID
   
-  if((
-        length(breaks)==nrow(levelsx)
-        ) & (
-        'col' %in% names(levelsx)
-        )
-  ){
-   # colours have been provided 
-    col = levelsx$col
-  }
-  
   weights = levelsx$freq
   x=levelsx$ID
   labels = levelsx$label
@@ -195,44 +238,52 @@ colourScale.numeric = function(x=NULL, breaks=5,
 		weights=NULL,...) {
 
 	xOrig = x
-
+	style = style[1]
+	eps=0.01
+	
+	# radar colours
 	if(is.character(col)){
-		if(col[1]=='radar'){
+		if(identical(col[1],'radar')){
 			col = radarCol
 		}
 	}
 	
-	
-	style = style[1]
-	if(!is.function(col)){		
-		if(is.matrix(col)| is.data.frame(col)) {
-			redCol = grep("^[[:space:]]*r(ed)?[[:space:]]*$", colnames(col), value=TRUE,ignore.case=TRUE)
-			blueCol = grep("^[[:space:]]*b(lue)?[[:space:]]*$", colnames(col), value=TRUE,ignore.case=TRUE)
-			greenCol = grep("^[[:space:]]*g(reen)?[[:space:]]*$", colnames(col), value=TRUE,ignore.case=TRUE)
-			if(!all(c(length(redCol),length(greenCol), length(blueCol))==1)) {
-				warning("col is a matrix but it's not clear which columns are red, green and blue")
-			}		
-			if(any(col[,c(redCol,greenCol,blueCol)] > 2 )) {
-				theMax = 255
-			} else{
-				theMax = 1
-			}
-			col = rgb(col[,redCol], col[,greenCol], col[,blueCol], maxColorValue=theMax)
+	# convert rgb colours to character string
+	if(is.matrix(col)| is.data.frame(col)) {
+		redCol = grep("^[[:space:]]*r(ed)?[[:space:]]*$", colnames(col), value=TRUE,ignore.case=TRUE)
+		blueCol = grep("^[[:space:]]*b(lue)?[[:space:]]*$", colnames(col), value=TRUE,ignore.case=TRUE)
+		greenCol = grep("^[[:space:]]*g(reen)?[[:space:]]*$", colnames(col), value=TRUE,ignore.case=TRUE)
+		if(!all(c(length(redCol),length(greenCol), length(blueCol))==1)) {
+			warning("col is a matrix but it's not clear which columns are red, green and blue")
+		}		
+		if(any(col[,c(redCol,greenCol,blueCol)] > 2 )) {
+			theMax = 255
+		} else{
+			theMax = 1
 		}
-		
-		colString = col
-		if(length(colString)==1){
+		col = rgb(col[,redCol], col[,greenCol], col[,blueCol], maxColorValue=theMax)
+	}
+	
+	
+	if(!is.function(col)){		
+		colName = col
+		colString = NULL
+		if(length(col)==1){
 			if(requireNamespace('RColorBrewer',quietly=TRUE)) {
-				col = function(n) RColorBrewer::brewer.pal(n, colString)[1:n]
+				col = function(n) RColorBrewer::brewer.pal(n, colName)[1:n]
 			} else {
 				col = function(n) heat.colors(n)
 			}
 		} else {
+			colString = col
+			colName = NULL
 			col = function(n) colString[1:n]
 		}
+	} else {
+		colString = NULL
+		colName = NULL
 	}
-
-	eps=0.01
+	
 	
 	
 	if(style=='unique'){
@@ -240,69 +291,85 @@ colourScale.numeric = function(x=NULL, breaks=5,
 
 		if(length(weights)!=length(x)) {
 			thetable = as.data.frame(table(ID=x))
-			thetable$ID = as.numeric(as.character(thetable$ID)) 
+			thetable$ID = as.numeric(as.character(thetable$ID))
 		} else {
-			thetable = tapply(weights, x,sum)
+			thetable = tapply(weights, x,sum, na.rm=TRUE)
 			thetable = data.frame(ID=as.numeric(names(thetable)),
 					Freq=thetable)
 		}
-    
+		
+		# put labels in table
+		if(length(labels) == length(breaks)) {
+			# labels are assigned to breaks
+			thetable$label = labels[match(thetable$ID,breaks)]
+		} else if(length(labels) == nrow(thetable)) {
+			# labels are assigned to x
+				thetable$label = labels
+		} else if (length(labels) == length(x)) {
+			# labels algined with x
+			thetable$label = labels[match(thetable$ID, x)]
+		} else {
+			# don't use labels
+			thetable$label = as.character(thetable$ID)
+		}
+
+		if(length(breaks) > 1) {
+
+		# breaks not in the table
+		notInX = which(! breaks %in% thetable$ID)
+		if(length(notInX))
+			thetable = rbind(thetable,
+					data.frame(ID=breaks[notInX],
+							Freq=rep(0,length(notInX)),
+							label = as.character(breaks[notInX]))
+			)
+		}
+		
+		# if colours is a vector see if it can be put into table
+		if (length(breaks) == length(colString)) {
+			thetable$col = colString[match(thetable$ID,breaks)]
+		} else if(nrow(thetable) == length(colString)) {
+			thetable$col = colString
+		} 
+		
+    shouldExclude = which(thetable$ID %in% exclude)
+    if(length(shouldExclude))
+      thetable[shouldExclude,'Freq'] = -1
+		
+		
     if(length(breaks)==1){
       # breaks is the maximum number of breaks
       thetable = thetable[order(thetable$Freq, decreasing=TRUE),]
       
-      shouldExclude = which(thetable$ID %in% exclude)
-      if(length(shouldExclude))
-        thetable = rbind(
-          thetable[-shouldExclude,],
-          thetable[shouldExclude,]
-          )
-      breaks = thetable[
-          seq(1,min(breaks,nrow(thetable))),'ID'
-          ]
-      
-    }
-    
-		notInX = which(! breaks %in% x)
-		if(length(notInX))
-			thetable = rbind(thetable,
-				data.frame(ID=breaks[notInX],
-						Freq=rep(0,length(notInX)))
-				)
-				
-		if(length(labels) == length(breaks)) {
-			thetable$label = labels[match(thetable$ID,breaks)]
-		} else {
-			if(length(labels) == length(xOrig)) {
-				thetable$label = labels[match(thetable$ID,xOrig)]
-			} else if(length(labels)==nrow(thetable)){
-				thetable$label = labels[order(thetable$ID)]
-			} else {
-				thetable$label = as.character(thetable$ID)
-			}
-		}	
-
-		if(length(breaks)==1) { 
-			# assume breaks is the number of unique values to assign colours to
-			thetableExc = thetable[!( thetable$ID %in% exclude |
-										thetable$label %in% exclude),]
-			ncol = min(c(breaks, nrow(thetableExc)))
-			breaks = thetableExc[order(thetableExc$Freq,decreasing=TRUE)[1:ncol] , 'ID']
+			ncol = min(
+					breaks,sum(thetable$Freq>=0) 
+			) 
+     	breaks = thetable[which(thetable$Freq>0)[1:ncol],	'ID']
 		}  else {
-			breaks = breaks[! ( breaks %in% exclude | 
-								breaks %in% thetable[thetable$label %in% exclude,'ID']
-								) ]
+			breaks = breaks[! ( breaks %in% exclude) ]
 		}
-		
-		thetable[match( breaks, thetable$ID),'col'] = col(length(breaks))
+
+		# assign colours if they're not yet in the table
+		if(!length(thetable$col)) {
+			thetable$col = NA
+			colString = col(length(breaks))
+			thetable[match( breaks, thetable$ID),'col'] = colString
+		} else {
+			# remove colours from excluded categories
+			thetable[thetable$Freq<0, 'col'] = NA
+		}
+
 		thetable = thetable[order(thetable$ID),]
 
-		
 		colVec = thetable$col
 		names(colVec) =as.character(thetable$ID)
 		breaks = thetable$ID
 		breaks = c(breaks[1]-1/2, breaks+c(diff(breaks)/2,1/2))
 	} else { # not unique breaks
+		
+			
+		
+		
 		if(length(exclude) & length(x)) {
 			toexclude = which(x %in% exclude)
 			x[toexclude]	= NA
