@@ -2,7 +2,7 @@
 library('knitr')
 opts_chunk$set(echo=TRUE,message=FALSE,
 		dev='png', 
-		fig.align='center',fig.pos='H',width=80,
+		fig.align='center',fig.pos='h',width=80,
 		fig.height=5,fig.width=3,out.width="0.3\\textwidth",
 		dev.args=list(bg='white')
 )
